==> sca4j-binding-jms-0.4.2-sources.jar: org/sca4j/binding/jms/runtime/JMSObjectFactory.java <==
/**
 * SCA4J
 * Copyright (c) 2009 - 2099 Service Symphony Ltd
 *
 * Licensed to you under the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.  A copy of the license
 * is included in this distrubtion or you may obtain a copy at
 *
 *    http://www.opensource.org/licenses/apache2.0.php
 *
 * Unless required by applicable law or agreed to in writing, software distributed
 * under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * This project contains code licensed from the Apache Software Foundation under
 * the Apache License, Version 2.0 and original code from project contributors.
 *
 *
 * Original Codehaus Header
 *
 * Copyright (c) 2007 - 2008 fabric3 project contributors
 *
 * Licensed to you under the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.  A copy of the license
 * is included in this distrubtion or you may obtain a copy at
 *
 *    http://www.opensource.org/licenses/apache2.0.php
 *
 * Unless required by applicable law or agreed to in writing, software distributed
 * under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * This project contains code licensed from the Apache Software Foundation under
 * the Apache License, Version 2.0 and original code from project contributors.
 *
 * Original Apache Header
 *
 * Copyright (c) 2005 - 2006 The Apache Software Foundation
 *
 * Apache Tuscany is an effort undergoing incubation at The Apache Software
 * Foundation (ASF), sponsored by the Apache Web Services PMC. Incubation is
 * required of all newly accepted projects until a further review indicates that
 * the infrastructure, communications, and decision making process have stabilized
 * in a manner consistent with other successful ASF projects. While incubation
 * status is not necessarily a reflection of the completeness or stability of the
 * code, it does indicate that the project has yet to be fully endorsed by the ASF.
 *
 * This product includes software developed by
 * The Apache Software Foundation (http://www.apache.org/).
 */
package org.sca4j.binding.jms.runtime;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.Queue;
import javax.jms.Session;
import javax.jms.Topic;

import org.sca4j.binding.jms.common.TransactionType;

/**
 * This is a factory class handling cache, recover. etc for a
 * connectionFactory/destination pair related JMS objects.
 */
public class JMSObjectFactory {
    
    private final ConnectionFactory connectionFactory;
    private final Destination destination;
    private final String destinationName;

    public JMSObjectFactory(ConnectionFactory connectionFactory, Destination destination, int cacheLevel) {
        try {
            this.connectionFactory = connectionFactory;
            this.destination = destination;
            destinationName = (destination instanceof Queue) ? ((Queue)  destination).getQueueName() : ((Topic)  destination).getTopicName();
        } catch (JMSException e) {
            throw new AssertionError(e);
        }
    }
    
    public String getDestinationName() {
        return destinationName;
    }

    public ConnectionFactory getConnectionFactory() {
        return connectionFactory;
    }

    public Connection getConnection() throws JMSException {
        return connectionFactory.createConnection();
    }

    public Destination getDestination() {
        return destination;
    }

    public Session getSession(Connection connection, TransactionType transactionType) throws JMSException {
        return connection.createSession(transactionType == TransactionType.LOCAL? true : false, Session.SESSION_TRANSACTED);
    }

}

==> sca4j-binding-jms-0.9.2-sources.jar: org/sca4j/binding/jms/runtime/JMSObjectFactory.java <==
/**
 * SCA4J
 * Copyright (c) 2009 - 2099 Service Symphony Ltd
 *
 * Licensed to you under the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.  A copy of the license
 * is included in this distrubtion or you may obtain a copy at
 *
 *    http://www.opensource.org/licenses/apache2.0.php
 *
 * Unless required by applicable law or agreed to in writing, software distributed
 * under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * This project contains code licensed from the Apache Software Foundation under
 * the Apache License, Version 2.0 and original code from project contributors.
 *
 *
 * Original Codehaus Header
 *
 * Copyright (c) 2007 - 2008 fabric3 project contributors
 *
 * Licensed to you under the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.  A copy of the license
 * is included in this distrubtion or you may obtain a copy at
 *
 *    http://www.opensource.org/licenses/apache2.0.php
 *
 * Unless required by applicable law or agreed to in writing, software distributed
 * under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * This project contains code licensed from the Apache Software Foundation under
 * the Apache License, Version 2.0 and original code from project contributors.
 *
 * Original Apache Header
 *
 * Copyright (c) 2005 - 2006 The Apache Software Foundation
 *
 * Apache Tuscany is an effort undergoing incubation at The Apache Software
 * Foundation (ASF), sponsored by the Apache Web Services PMC. Incubation is
 * required of all newly accepted projects until a further review indicates that
 * the infrastructure, communications, and decision making process have stabilized
 * in a manner consistent with other successful ASF projects. While incubation
 * status is not necessarily a reflection of the completeness or stability of the
 * code, it does indicate that the project has yet to be fully endorsed by the ASF.
 *
 * This product includes software developed by
 * The Apache Software Foundation (http://www.apache.org/).
 */
package org.sca4j.binding.jms.runtime;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.Session;

import org.sca4j.binding.jms.common.TransactionType;

/**
 * This is a factory class handling cache, recover. etc for a
 * connectionFactory/destination pair related JMS objects.
 */
public class JMSObjectFactory {
    
    private final ConnectionFactory connectionFactory;
    private final Destination destination;
    private final Destination responseDestination;

    public JMSObjectFactory(ConnectionFactory connectionFactory, Destination destination, Destination responseDestination) {
        this.connectionFactory = connectionFactory;
        this.destination = destination;
        this.responseDestination = responseDestination;
    }
    
    public Destination getResponseDestination() {
        return responseDestination;
    }

    public ConnectionFactory getConnectionFactory() {
        return connectionFactory;
    }

    public Connection getConnection() throws JMSException {
        return connectionFactory.createConnection();
    }

    public Destination getDestination() {
        return destination;
    }

    public Session getSession(Connection connection, TransactionType transactionType) throws JMSException {
        if (transactionType == TransactionType.LOCAL) {
            return connection.createSession(true, Session.AUTO_ACKNOWLEDGE);
        } else {
            return connection.createSession(true, Session.SESSION_TRANSACTED);
        }
    }

}
